function [h,edge]=myhisto(x,N,odd,scale,sym)
%HISTO    plot a  histogram
%  
%         [h,edge]=histo(X)
%         [h,edge]=histo(X,M,odd,scale,S) : 
%             
%
% Input:    X	   datas,
%	    M 	   approximate number of bins,
%           odd	   should be 0 or 1 for placement of bins. Least significant 
%         	   digit of bin width will always be 1, 2 or 5. 
%	    scale  should be one for scaling in order to have the area 1 under
%         	   the histogram instead of area n. 
%	    S 	   string which specifies the plot linestyle
% Output:   egde   edges of the classes of the histogram
%           h      h(i) is the number of values in X that belong to
%                  [edge(i), edge(i+1)[ 

%       Anders Holtsberg, 14-12-94
%       Copyright (c) Anders Holtsberg

%       Revision 04-05-2000 Mathematique Universite de Paris-Sud

if nargin < 2, N = []; end
if nargin < 3, odd = []; end
if nargin < 4, scale = []; end
if nargin < 5, sym='b'; end
if isempty(N)
   N = ceil(4*sqrt(sqrt(length(x))));
end
if isempty(odd)
   odd = 0;
end
if isempty(scale)
   scale = 0;
end

mn = min(x);
mx = max(x);
d = (mx - mn)/N*2;
e = floor(log(d)/log(10));
m = floor(d/10^e);
if m > 5
   m = 5;
elseif m > 2
   m = 2;
end
d = m * 10^e;
mn = (floor(mn/d)-1)*d - odd*d/2;
mx = (ceil(mx/d)+1)*d + odd*d/2;
limits = mn:d:mx;

f = zeros(1,length(limits)-1);
for i = 1:length(limits)-1
   f(i) = sum(x>=limits(i) & x<limits(i+1));
end

xx = [limits ;limits ;limits];
xx = xx(:);
xx = xx(2:length(xx)-1);
yy = [f*0; f; f];
yy = [yy(:);  0];
if scale, yy = yy/length(x)/d; end
plot(xx,yy,sym)
if nargout>0 
   h=f;
   edge=limits;
end

